#[non_exhaustive]pub enum MergeStrategy {
Deep,
Fallback,
}Expand description
Strategy for merging history data from multiple providers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Deep
Fetch from all eligible providers concurrently and merge their data. This produces the most complete dataset by backfilling gaps from lower-priority providers.
Fallback
Iterate through providers sequentially and stop as soon as one returns a non-empty dataset. This is more economical for API rate limits but may miss data from lower-priority providers.